Queue
-----
The Queue object automatically plays the next song when the current one is done playing.
Queue inherits from list so all of the list's methods can be used (ex. :meth:`pop`, :meth:`append`, :meth:`__iter__`)

.. autoclass:: songbird.queue.Queue
    :show-inheritance:
    :inherited-members:
    :private-members: __add__, __iadd__
